package com.as.common.utils;
import org.apache.poi.ss.usermodel.*;  
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import com.as.member.dao.ViewAmountAccountMember;

import java.io.FileOutputStream;  
import java.io.IOException;  
import java.lang.reflect.Field;
import java.math.BigDecimal;
import java.nio.file.Paths;  
import java.text.SimpleDateFormat;  
import java.util.Date;  
import java.util.List;  


public class ExportExcel {
	private static final String OUTPUT_DIRECTORY = "D:\\as_excel";
	public <T> String generateExcel(List<T> entities) {  
        Workbook workbook = new XSSFWorkbook();  
        Sheet sheet = workbook.createSheet("Data");  
  
        // 获取实体类的Class对象  
        Class<?> entityClass = entities.get(0).getClass();  
        
        // 创建表头行  
        Row headerRow = sheet.createRow(0);  
        int columnIndex = 0;  
        int columnIndex2 = 1;  
        // 遍历实体类的所有字段，并设置表头  
        for (Field field : entityClass.getDeclaredFields()) {  
            field.setAccessible(true); // 设置字段为可访问，以获取私有字段的值  
         // 检查字段上是否有MyAnnotation注解  
            if (field.isAnnotationPresent(ExcelAnnotation.class)) {  
                // 获取注解实例  
            	ExcelAnnotation annotation = field.getAnnotation(ExcelAnnotation.class);  
                // 获取注解的value属性值  
            	Cell headerCell = headerRow.createCell(columnIndex++);  
                headerCell.setCellValue(annotation.value()); // 使用字段名作为表头 
               
            }  
             
        }  
  
        // 假设第一行是表头，从第二行开始填充数据  
        for (T entity : entities) { 
        	 Row row = sheet.createRow(columnIndex2++);  
             int columnNum = 0;  
   
             // 获取实体类的Class对象  
             Class<?> entityClassValue = entity.getClass();  
             for (Field fieldValue : entityClassValue.getDeclaredFields()) { 
            	 if (fieldValue.isAnnotationPresent(ExcelAnnotation.class)) { 
            		 try {
                    	 // 设置字段为可访问，以获取私有字段的值  
                    	 fieldValue.setAccessible(true);  
                    	 
                    	 // 创建单元格并设置值  
                    	 Cell cell = row.createCell(columnNum++);  
                    	 Object fieldValueData = fieldValue.get(entity);
                    	   // 根据字段值的类型设置单元格的值  
                         if (fieldValueData != null) {  
                        	 if (fieldValueData instanceof String) {  
                                 cell.setCellValue((String) fieldValueData);  
                             } else if (fieldValueData instanceof Integer) {  
                                 cell.setCellValue((Integer) fieldValueData);  
                             } else if (fieldValueData instanceof Long) {  
                                 cell.setCellValue((Long) fieldValueData);  
                             } else if (fieldValueData instanceof Double) {  
                                 cell.setCellValue((Double) fieldValueData);  
                             } else if (fieldValueData instanceof Float) {  
                                 cell.setCellValue((Float) fieldValueData);  
                             } else if (fieldValueData instanceof Short) {  
                                 cell.setCellValue((Short) fieldValueData);  
                             } else if (fieldValueData instanceof Byte) {  
                                 cell.setCellValue((Byte) fieldValueData);  
                             } else if (fieldValueData instanceof Boolean) {  
                                 cell.setCellValue((Boolean) fieldValueData);  
                             } else if (fieldValueData instanceof Date) {  
                            	// 创建SimpleDateFormat对象，并指定日期时间的格式  
                                 SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");  
                           
                                 // 使用SimpleDateFormat的format方法将Date对象转换为字符串  
                                 String formattedDate = sdf.format((Date) fieldValueData);  
                                 cell.setCellValue(formattedDate);  
                             } else if (fieldValueData instanceof BigDecimal) {  
                            	 BigDecimal value = (BigDecimal) fieldValueData;

                                 cell.setCellValue(value.toString());  
                             } else {  
                                 // 如果字段是其他类型或者未知类型，可以设置为字符串  
                                 cell.setCellValue(fieldValue.toString());  
                             }  
                         } 
    				} catch (IllegalArgumentException e) {
    					// TODO Auto-generated catch block
    					e.printStackTrace();
    				} catch (IllegalAccessException e) {
    					// TODO Auto-generated catch block
    					e.printStackTrace();
    				} // 获取字段的值  
            	 }
                
             }
        }
        // 自动调整列宽  
        for (int i = 0; i < headerRow.getLastCellNum(); i++) {  
            sheet.autoSizeColumn(i);  
        }  
        // 生成文件名  
        String fileName = entityClass.getSimpleName() + "_" + new SimpleDateFormat("yyyyMMddHHmmSS").format(new Date()) + ".xlsx";  
        String filePath = Paths.get(OUTPUT_DIRECTORY, fileName).toString();  
  
        // 写入文件并关闭Workbook  
        try (FileOutputStream outputStream = new FileOutputStream(filePath)) {  
            workbook.write(outputStream);  
        } catch (IOException e) {  
            e.printStackTrace();  
            // 处理异常  
        } finally {  
            try {  
                workbook.close();  
            } catch (IOException e) {  
                e.printStackTrace();  
            }  
        }  
  
        // 返回文件路径  
        return filePath;  
    }  
}
	 
