package com.as.member.controller;

import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.as.common.json.requestJSON;
import com.as.common.jwt.UserLoginToken;
import com.as.member.dao.AmountAccount;
import com.as.member.dao.Project;
import com.as.member.service.AmountAccountService;
import com.as.user.controller.UserContorller;
import com.as.user.dao.UserData;
import com.as.user.service.UserService;
import com.auth0.jwt.JWT;

import jakarta.servlet.http.HttpServletRequest;

@RestController
@RequestMapping("/amountAccount")
public class AmountAccountContorller {
	@Autowired
	AmountAccountService amountAccountService;
    @Autowired
    UserService userService;
    
    
	private static final Logger logger = LogManager.getLogger(AmountAccountContorller.class);
	@UserLoginToken
    @RequestMapping(value = "/findAmountAccountList", method = RequestMethod.POST)
    public requestJSON<List<AmountAccount>> findProjectList(@RequestBody AmountAccount data, HttpServletRequest request) {
        logger.info("进入findAmountAccountList方法，接收到数据data:" + data.toString());
        requestJSON<List<AmountAccount>> json = new requestJSON<List<AmountAccount>>();
        try {
            
            json.setCode(200);
            json.setData(amountAccountService.findAmountAccountList(data));
            json.setMessage("查询成功");
            return json;
        } catch (Exception e) {
            // 捕获异常，返回错误状态码和错误消息
            json.setCode(500);
            json.setMessage("错误" + e.getMessage());
            return json;
        }
    }
 	
 	@UserLoginToken
    @RequestMapping(value = "/addAmountAccount", method = RequestMethod.POST)
    public requestJSON<AmountAccount> addProject(@RequestBody AmountAccount data, HttpServletRequest request) {
        logger.info("进入addAmountAccount方法，接收到数据data:" + data.toString());
        requestJSON<AmountAccount> json = new requestJSON<AmountAccount>();
        String header = request.getHeader("Authorization");
        String userId = JWT.decode(header).getAudience().get(0);
        UserData findUserByUserId = userService.findUserByUserId(Integer.parseInt(userId));
      
        try {
           
            json.setCode(200);
            json.setData(amountAccountService.addAmountAccount(data, findUserByUserId.getUserName()));
            json.setMessage("增加成功");
            return json;
        } catch (Exception e) {
            // 捕获异常，返回错误状态码和错误消息
            json.setCode(500);
            json.setMessage("错误" + e.getMessage());
            return json;
        }
    }
 	
 	@UserLoginToken
    @RequestMapping(value = "/editAmountAccount", method = RequestMethod.POST)
    public requestJSON<AmountAccount> editProject(@RequestBody AmountAccount data, HttpServletRequest request) {
        logger.info("进入editAmountAccount方法，接收到数据data:" + data.toString());
        requestJSON<AmountAccount> json = new requestJSON<AmountAccount>();
        String header = request.getHeader("Authorization");
        String userId = JWT.decode(header).getAudience().get(0);
        UserData findUserByUserId = userService.findUserByUserId(Integer.parseInt(userId));
      
        try {
            
            json.setCode(200);
            json.setData(amountAccountService.editAmountAccount(data, findUserByUserId.getUserName()));
            json.setMessage("修改成功");
            return json;
        } catch (Exception e) {
            // 捕获异常，返回错误状态码和错误消息
            json.setCode(500);
            json.setMessage("错误" + e.getMessage());
            return json;
        }
    }
	
}
