package com.as.member.controller;/**
 * @author： lyu
 * @date： 2024-03-31 10:35
 * @version 1.0
 */

import com.as.common.json.requestJSON;
import com.as.common.jwt.UserLoginToken;
import com.as.common.utils.UserRole;
import com.as.member.dao.MemberData;
import com.as.member.service.MemberService;
import com.as.user.controller.UserContorller;
import com.as.user.service.UserService;
import com.auth0.jwt.JWT;
import jakarta.servlet.http.HttpServletRequest;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;

/**
 * @version 1.0
 * @author： lyu
 * @date： 2024-03-31 10:35
 */
@RestController
@RequestMapping("/member")
public class MemberContorller {
    @Autowired
    UserRole UserRole;
    @Autowired
    private MemberService memberService;
    private static final Logger logger = LogManager.getLogger(UserContorller.class);
    @UserLoginToken
    @RequestMapping(value = "/getMember", method = RequestMethod.POST)
    public requestJSON<List<MemberData>> getUser(@RequestBody MemberData data) {
        logger.info("进入getMember方法，接收到数据data:" + data.toString());
        requestJSON<List<MemberData>> json = new requestJSON<>();
        json.setCode(200);
        json.setData(memberService.find(data));
        json.setMessage("成功");

        return json;
    }

    /**
     * 通过POST请求创建会员信息。
     * @param data 包含会员信息的请求体，通过JSON格式传递。
     * @param request 客户端的HTTP请求，用于获取请求头信息。
     * @return 返回一个包含操作结果的JSON对象，包括操作状态码、消息和操作结果数据。
     */
    @UserLoginToken
    @RequestMapping(value = "/createdMember", method = RequestMethod.POST)
    public requestJSON<Integer> createdMember(@RequestBody MemberData data, HttpServletRequest request) {
        logger.info("进入createdMember方法，接收到数据data:" + data.toString());
        // 从请求头中解析用户ID
        String userId = JWT.decode(request.getHeader("Authorization")).getAudience().get(0);
        //创建查询是否已经有会员信息
        MemberData findMemberId =new MemberData();
        requestJSON<Integer> json = new requestJSON<>();
        // 设置操作人的创建者ID
        data.setCreatedBy(userId);
        try {
            findMemberId.setMemberId("HY"+data.getMembershipPhone());
            List<MemberData> idNum = memberService.find(findMemberId);
           if (idNum.size()>0){
               throw new Exception("会员信息已存在，请核实！！！");
           }
            // 尝试创建成员，成功则返回操作状态码和消息
            json.setCode(200);
            json.setData(memberService.createdMember(data));
            json.setMessage("新增成功");
            return json;
        } catch (Exception e) {
            // 捕获异常，返回错误状态码和错误消息
            json.setCode(500);
            json.setMessage("错误" + e.getMessage());
            return json;
        }
    }
    /**
     * 充值方法，这边要做两件事情，第一件事就是将金额加到as_member中的amount充值累计金额 以及 balance 充值金额上
     * 第二件事就是增加一个充值历史。
     * @param data
     * @param request
     * @return
     */
    @UserLoginToken
    @RequestMapping(value = "/rechargeMember", method = RequestMethod.POST)
    public requestJSON<Object> rechargeMember(@RequestBody HashMap<String,Object> data, HttpServletRequest request){
    	logger.info("进入rechargeMember方法，接收到数据data:" + data.toString());
    	// 获取用户名
    	String userName = UserRole.getUserName(request);
    	
    	requestJSON<Object> json = new requestJSON<>();
    	 try {
         
             json.setCode(200);
             json.setData(memberService.rechargeMember(data, userName));
             json.setMessage("新增成功");
             return json;
         } catch (Exception e) {
             // 捕获异常，返回错误状态码和错误消息
             json.setCode(500);
             json.setMessage("错误" + e.getMessage());
             return json;
         }
    	
    }
}
