package com.as.member.controller;

import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.as.common.json.requestJSON;
import com.as.common.jwt.UserLoginToken;
import com.as.member.dao.MemberData;
import com.as.member.dao.Project;
import com.as.member.service.ProjectService;
import com.as.user.dao.UserData;
import com.as.user.service.UserService;
import com.as.workflow.dao.WorkFlowEntity;
import com.auth0.jwt.JWT;

import jakarta.servlet.http.HttpServletRequest;

import org.apache.logging.log4j.Logger;



@RestController
@RequestMapping("/project")
public class ProjectContorller {
	@Autowired
	ProjectService projectService;
    @Autowired
    UserService userService;
	
	private static final Logger logger = LogManager.getLogger(ProjectContorller.class);
	
	 	@UserLoginToken
	    @RequestMapping(value = "/findProjectList", method = RequestMethod.POST)
	    public requestJSON<List<Project>> findProjectList(@RequestBody Project data, HttpServletRequest request) {
	        logger.info("进入findProjectList方法，接收到数据data:" + data.toString());
	        requestJSON<List<Project>> json = new requestJSON<List<Project>>();
	        try {
	            // 尝试创建成员，成功则返回操作状态码和消息
	            json.setCode(200);
	            json.setData(projectService.findProjectList(data));
	            json.setMessage("查询成功");
	            return json;
	        } catch (Exception e) {
	            // 捕获异常，返回错误状态码和错误消息
	            json.setCode(500);
	            json.setMessage("错误" + e.getMessage());
	            return json;
	        }
	    }
	 	
	 	@UserLoginToken
	    @RequestMapping(value = "/addProject", method = RequestMethod.POST)
	    public requestJSON<Project> addProject(@RequestBody Project data, HttpServletRequest request) {
	        logger.info("进入addProject方法，接收到数据data:" + data.toString());
	        requestJSON<Project> json = new requestJSON<Project>();
	        String header = request.getHeader("Authorization");
	        String userId = JWT.decode(header).getAudience().get(0);
	        UserData findUserByUserId = userService.findUserByUserId(Integer.parseInt(userId));
	      
	        try {
	            // 尝试创建成员，成功则返回操作状态码和消息
	            json.setCode(200);
	            json.setData(projectService.addProject(data, findUserByUserId.getUserName()));
	            json.setMessage("增加成功");
	            return json;
	        } catch (Exception e) {
	            // 捕获异常，返回错误状态码和错误消息
	            json.setCode(500);
	            json.setMessage("错误" + e.getMessage());
	            return json;
	        }
	    }
	 	
	 	@UserLoginToken
	    @RequestMapping(value = "/editProject", method = RequestMethod.POST)
	    public requestJSON<Project> editProject(@RequestBody Project data, HttpServletRequest request) {
	        logger.info("进入addProject方法，接收到数据data:" + data.toString());
	        requestJSON<Project> json = new requestJSON<Project>();
	        String header = request.getHeader("Authorization");
	        String userId = JWT.decode(header).getAudience().get(0);
	        UserData findUserByUserId = userService.findUserByUserId(Integer.parseInt(userId));
	      
	        try {
	            // 尝试创建成员，成功则返回操作状态码和消息
	            json.setCode(200);
	            json.setData(projectService.editProject(data, findUserByUserId.getUserName()));
	            json.setMessage("修改成功");
	            return json;
	        } catch (Exception e) {
	            // 捕获异常，返回错误状态码和错误消息
	            json.setCode(500);
	            json.setMessage("错误" + e.getMessage());
	            return json;
	        }
	    }
	 	
	 	@UserLoginToken
	    @RequestMapping(value = "/findProjectNameList", method = RequestMethod.POST)
	    public requestJSON<List<String>> findProjectNameList(@RequestBody Project data, HttpServletRequest request) {
	        logger.info("进入addProject方法，接收到数据data:" + data.toString());
	        requestJSON<List<String>> json = new requestJSON<List<String>>();

	      
	        try {
	            // 尝试创建成员，成功则返回操作状态码和消息
	            json.setCode(200);
	            json.setData(projectService.findProjectNameList());
	            json.setMessage("查询成功");
	            return json;
	        } catch (Exception e) {
	            // 捕获异常，返回错误状态码和错误消息
	            json.setCode(500);
	            json.setMessage("错误" + e.getMessage());
	            return json;
	        }
	    }
	 	
	 	@UserLoginToken
	    @RequestMapping(value = "/delProject", method = RequestMethod.POST)
	    public requestJSON<Integer> delProject(@RequestBody Project data, HttpServletRequest request) {
	        logger.info("进入delProject方法，接收到数据data:" + data.toString());
	        requestJSON<Integer> json = new requestJSON<Integer>();
	        try {
	            // 尝试创建成员，成功则返回操作状态码和消息
	            json.setCode(200);
	            json.setData(projectService.delProjectById(data.getSid()));
	            json.setMessage("删除成功");
	            return json;
	        } catch (Exception e) {
	            // 捕获异常，返回错误状态码和错误消息
	            json.setCode(500);
	            json.setMessage("错误" + e.getMessage());
	            return json;
	        }
	    }
}
