package com.as.member.service.impl;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.as.common.utils.StringUtils;
import com.as.member.dao.AmountAccount;
import com.as.member.dao.MemberData;
import com.as.member.dao.MemberTopUpData;
import com.as.member.dao.Project;
import com.as.member.mapper.AmountAccountMapper;
import com.as.member.mapper.MemberMapper;
import com.as.member.mapper.MemberTopUpDataMapper;
import com.as.member.mapper.ProjectMapper;
import com.as.member.service.AmountAccountService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

@Service
public class AmountAccountServiceImpl  implements AmountAccountService {

	@Autowired
	AmountAccountMapper amountAccountMapper;
	@Autowired
	MemberMapper memberMapper;
	@Autowired
	MemberTopUpDataMapper memberTopUpDataMapper;
	@Autowired
	ProjectMapper projectMapper;
	
	@Override
	public List<AmountAccount> findAmountAccountList(AmountAccount date) throws Exception {
		LambdaQueryWrapper<AmountAccount> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(StringUtils.isNotEmpty(date.getProjectName()), AmountAccount::getProjectName, date.getProjectName());
		queryWrapper.ge(StringUtils.isNotEmpty(date.getCreatedStartDt()) , AmountAccount::getCreatedDt, date.getCreatedStartDt()); // 大于等于
		queryWrapper.le(StringUtils.isNotEmpty(date.getCreatedEndDt()), AmountAccount::getCreatedDt, date.getCreatedEndDt());// 小于等于
		List<AmountAccount> selectList = amountAccountMapper.selectList(queryWrapper);
		return selectList;
	}

	@Override
	public AmountAccount addAmountAccount(AmountAccount date, String userName) throws Exception {
		// TODO Auto-generated method stub
		// 转换数据
		BigDecimal quantity = new BigDecimal(date.getQuantity());  
	
		// 查询项目是什么
		Project selectById = projectMapper.selectById(date.getProjectSid());
		BigDecimal unitPrice = selectById.getUnitPrice();
		String projectName = selectById.getProjectName();
		// 总共花了多少钱
		BigDecimal multiply = unitPrice.multiply(quantity);
		// 查询是哪个会员
		QueryWrapper<MemberData> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("member_id", date.getAsMemberSid());
		MemberData MemberSelectOne = memberMapper.selectOne(queryWrapper);
		// 修改会员的钱款
		BigDecimal subtract = MemberSelectOne.getBalance().subtract(multiply);
		if(subtract.compareTo(BigDecimal.ZERO)<0) {
			throw new Exception("余额不足！");
		}
		MemberSelectOne.setBalance(subtract);
		memberMapper.updateById(MemberSelectOne);
		/**
		 *  增加一个记录 作废
		MemberTopUpData memberTopUpData = new MemberTopUpData();
    	memberTopUpData.setAsMemberSid(MemberSelectOne.getMemberId());
    	memberTopUpData.setTopUpMoney(multiply);
    	memberTopUpData.setCreatedBy(userName);
    	memberTopUpData.setCreatedDt(new Date());
    	memberTopUpData.setStatus("sub");
    	memberTopUpDataMapper.insert(memberTopUpData);
    	 */
    	
    	// 执行项目新增
		date.setCreatedDt(new Date());
    	date.setCreatedBy(userName);
    	date.setStatus("否");
    	date.setUnitPrice(unitPrice);
    	date.setTotalPrice(multiply);
    	date.setProjectName(projectName);
    	int amountAccountinsert = amountAccountMapper.insert(date);
    	if(amountAccountinsert > 0) {
			Long sid = date.getSid();

			return amountAccountMapper.selectById(sid);
		}else {
			throw new Exception("查询返回失败，查询后并未查找到新增值");
		}
	}

	@Override
	public AmountAccount editAmountAccount(AmountAccount date, String userName) throws Exception {
			// TODO Auto-generated method stub
			// date.setUpdateBy(userName);
			// date.setUpdateDt(new Date());
					if("是".equals(date.getStatus())) {
					BigDecimal totalPrice = date.getTotalPrice();
					// 查询是哪个会员
					QueryWrapper<MemberData> queryWrapper = new QueryWrapper<>();
					queryWrapper.eq("member_id", date.getAsMemberSid());
					MemberData MemberSelectOne = memberMapper.selectOne(queryWrapper);
					MemberSelectOne.setBalance(MemberSelectOne.getBalance().add(totalPrice));
					memberMapper.updateById(MemberSelectOne);
				}
				
				int updateById = amountAccountMapper.updateById(date);
				if(updateById > 0) {
					AmountAccount selectById = amountAccountMapper.selectById(date.getSid());
					return selectById;
				}else {
					throw new Exception("查询返回失败，查询后并未查找到修改值");
					}
	}

	@Override
	public int delAmountAccountById(Integer id) throws Exception {
		// TODO Auto-generated method stub
		return 0;
	}

}
