package com.as.member.service.impl;

import com.as.common.utils.StringUtils;
import com.as.common.utils.TimeUtils;
import com.as.member.dao.Hospital;
import com.as.member.dao.MemberData;
import com.as.member.dao.MemberTopUpData;
import com.as.member.mapper.HospitalMappper;
import com.as.member.mapper.MemberMapper;
import com.as.member.mapper.MemberTopUpDataMapper;
import com.as.member.service.MemberService;
import com.as.user.dao.MenuData;
import com.as.user.mapper.MenuMapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @version 1.0
 * @author： lyu
 * @date： 2024-03-31 10:53
 */
@Service
public class MemberServiceImpl implements MemberService {
    private static final Logger logger = LogManager.getLogger(MemberServiceImpl.class);

    @Autowired
    private MemberMapper memberMapper;
    @Autowired
    private HospitalMappper hospitalMappper;
    @Autowired
    private MemberTopUpDataMapper memberTopUpDataMapper;
    /**
     * 按医院编码查询归属该医院下的患者信息
     *
     * @param memberData 包含要查询的成员信息的对象。可以使用其中的属性如成员ID和医院ID来过滤结果。
     * @return 返回一个成员数据列表，这些数据与提供的memberData匹配。
     */
    @Override
    public List<MemberData> find(MemberData memberData) {
        logger.info("进入find方法，接收到数据data:" + memberData.toString());
        LambdaQueryWrapper<Hospital> lambdaQueryWrapper = new LambdaQueryWrapper<Hospital>();
        lambdaQueryWrapper.eq(Hospital::getHospitalName, memberData.getHospitalName());
        Hospital selectOne = hospitalMappper.selectOne(lambdaQueryWrapper);
        // 创建查询包装器，并根据memberData的属性设置查询条件
        LambdaQueryWrapper<MemberData> queryWrapper = new LambdaQueryWrapper<>();
        // 如果memberData的memberId不为空，则添加等于memberData的hospitalSid的查询条件
        queryWrapper.eq(MemberData::getHospitalSid, selectOne.getHospitalId());
        queryWrapper.eq(StringUtils.isNotEmpty(memberData.getMemberId()), MemberData::getMemberId, memberData.getMemberId());
        // 根据查询条件从数据库中选择成员数据列表
        List<MemberData> memberList = memberMapper.selectList(queryWrapper);
        return memberList;
    }

    @Override
    public List<MemberTopUpData> topUpMoney(MemberTopUpData data) {
        memberMapper.insert(data);
        return null;
    }

    @Override
    public Integer createdMember(MemberData data) {
    	// 医院转义
    	QueryWrapper<Hospital> queryWrapper = new QueryWrapper<>();
    	queryWrapper.eq("hospital_name", data.getHospitalName());
    	List<Map<String, Object>> selectMaps = hospitalMappper.selectMaps(queryWrapper);
    	//    	System.out.println(selectMaps.toString());
    	data.setHospitalSid((int)selectMaps.get(0).get("hospital_id"));
        data.setMemberId("HY" + data.getMembershipPhone());
        data.setCreatedDt(new Date());
        data.setMembershipLv(1);
        //首次创建会员卡，取充值总金额赋值给卡余额
        data.setBalance(data.getAmount());
        return memberMapper.insert(data);

    }
    /**
     *  充值方法，这边要做两件事情，第一件事就是将金额加到as_member中的amount充值累计金额 以及 balance 充值金额上
     * 	第二件事就是增加一个充值历史。
     * 	我将返回修改后的值保证数据可查询
     */
    @Override
    public HashMap<String, Object> rechargeMember(HashMap<String,Object> data,  String userName) {
    	HashMap<String, Object> map = new HashMap<String, Object>();
    	
    	QueryWrapper<MemberData> queryWrapper = new QueryWrapper<>();
    	queryWrapper.eq("member_id", data.get("memberId"));
    	BigDecimal change = new BigDecimal(data.get("amount").toString());  
    	MemberData selectOne = memberMapper.selectOne(queryWrapper);

    	selectOne.setBalance(selectOne.getBalance().add(change));
    	selectOne.setAmount(selectOne.getAmount().add(change));
    	memberMapper.updateById(selectOne);
    	MemberData selectOneBefoerChange = memberMapper.selectOne(queryWrapper);
    	map.put("memberInfo", selectOneBefoerChange);
    	
    	MemberTopUpData memberTopUpData = new MemberTopUpData();
    	memberTopUpData.setAsMemberSid(selectOneBefoerChange.getMemberId());
    	memberTopUpData.setTopUpMoney(change);
    	memberTopUpData.setCreatedBy(userName);
    	memberTopUpData.setCreatedDt(new Date());
    	memberTopUpData.setStatus("add");
    	int insert = memberTopUpDataMapper.insert(memberTopUpData);
    	if(insert > 0) {
    		Long sid = memberTopUpData.getSid();

    		map.put("rechargeList", memberTopUpDataMapper.selectById(sid));
    	}
    	
    	return map;
    	
    }

}
