package com.as.member.service.impl;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.as.common.utils.StringUtils;
import com.as.member.dao.Project;
import com.as.member.mapper.ProjectMapper;
import com.as.member.service.ProjectService;
import com.as.workflow.dao.ViewWorkFlowEntity;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

@Service
public class ProjectServiceImpl  implements ProjectService {

	@Autowired
	ProjectMapper projectMapper;
	
	
	@Override
	public List<Project> findProjectList(Project date)  throws Exception{
		// TODO Auto-generated method stub
		LambdaQueryWrapper<Project> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(StringUtils.isNotEmpty(date.getProjectName()), Project::getProjectName, date.getProjectName());
		queryWrapper.ge(StringUtils.isNotEmpty(date.getCreatedStartDt()) , Project::getCreatedDt, date.getCreatedStartDt()); // 大于等于
		queryWrapper.le(StringUtils.isNotEmpty(date.getCreatedEndDt()), Project::getCreatedDt, date.getCreatedEndDt());// 小于等于
		List<Project> selectList = projectMapper.selectList(queryWrapper);
		return selectList;
	}

	@Override
	public Project addProject(Project date, String userName)  throws Exception{
		// TODO Auto-generated method stub
		QueryWrapper<Project> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("project_name", date.getProjectName());
		List<Project> selectList = projectMapper.selectList(queryWrapper);
		if(selectList.size()!=0) {
			throw new Exception("项目名重复，请检查！");
		}
		date.setCreatedBy(userName);
		date.setCreatedDt(new Date());
		int insert = projectMapper.insert(date);
		
		if(insert > 0) {
			Long sid = date.getSid();

			return projectMapper.selectById(sid);
		}else {
			throw new Exception("查询返回失败，查询后并未查找到新增值");
		}

	}

	@Override
	public Project editProject(Project date, String userName)  throws Exception{
		// TODO Auto-generated method stub
		date.setUpdateBy(userName);
		date.setUpdateDt(new Date());
		int updateById = projectMapper.updateById(date);
		if(updateById > 0) {
			Project selectById = projectMapper.selectById(date.getSid());
			return selectById;
		}else {
			throw new Exception("查询返回失败，查询后并未查找到修改值");
			}
		
	}

	@Override
	public int delProjectById(Long id)  throws Exception{
		// TODO Auto-generated method stub
		int deleteById = projectMapper.deleteById(id);
		return deleteById;
	}

	@Override
	public List<String> findProjectNameList() throws Exception {
		QueryWrapper<Project> queryWrapper = new QueryWrapper<>();
		List<Map<String, Object>> selectMaps = projectMapper.selectMaps(queryWrapper);

		List<String> projectNames = selectMaps.stream()  
                .map(map -> (String) map.get("project_name")) // 将每个map中的projectName转换为String  
                .collect(Collectors.toList()); // 收集结果到List<String> 
		return projectNames;
	}

}
