package com.as.workflow.service.impl;

import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import com.as.common.exception.base.BaseException;
import com.as.common.utils.StringUtils;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.as.user.dao.Role;
import com.as.user.dao.UserData;
import com.as.workflow.dao.ViewWorkFlowEntity;
import com.as.workflow.dao.WorkFlowEntity;
import com.as.workflow.mapper.ViewWorkFlowMapper;
import com.as.workflow.mapper.WorkFlowMapper;
import com.as.workflow.service.WorkFlowService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
@Service
public class WorkFlowServiceImpl implements WorkFlowService {
	 	@Autowired
	    private ViewWorkFlowMapper viewWorkFlowMapper;
	 	@Autowired
	    private WorkFlowMapper workFlowMapper;
	 	static String[] stateList = {"工单开始","取未煎药","未煎药送达","煎药完成","取已煎药","己煎药送回"};
		/**
 		 * 查询所有状态的数量
 		 */
	 	@Override
	 	public List<HashMap<String,Object>> getStatus(WorkFlowEntity workFlowEntity){
	 		HashMap<String, Object> hashMapOne = new HashMap<String,Object>();
	 		HashMap<String, Object> hashMapTwo = new HashMap<String,Object>();
	 		HashMap<String, Object> hashMapthree = new HashMap<String,Object>();
	 		HashMap<String, Object> hashMapfour = new HashMap<String,Object>();
	 		List<HashMap<String, Object>> list = new ArrayList<HashMap<String,Object>>();
	 		LambdaQueryWrapper<ViewWorkFlowEntity> queryWrapper = new LambdaQueryWrapper<>();
	 		queryWrapper.like(StringUtils.isNotEmpty(workFlowEntity.getWorkOrderNo()), ViewWorkFlowEntity::getWorkOrderNo, workFlowEntity.getWorkOrderNo());
			queryWrapper.eq(StringUtils.isNotEmpty(workFlowEntity.getWorkPlace()), ViewWorkFlowEntity::getWorkPlace, workFlowEntity.getWorkPlace());
			queryWrapper.like(StringUtils.isNotEmpty(workFlowEntity.getPatientName()), ViewWorkFlowEntity::getPatientName, workFlowEntity.getPatientName());
			
			queryWrapper.ge(StringUtils.isNotEmpty(workFlowEntity.getCreatedStartDt()) , ViewWorkFlowEntity::getCreatedDt, workFlowEntity.getCreatedStartDt()); // 大于等于
			queryWrapper.le(StringUtils.isNotEmpty(workFlowEntity.getCreatedEndDt()), ViewWorkFlowEntity::getCreatedDt, workFlowEntity.getCreatedEndDt());// 小于等于
			
			hashMapTwo.put("value", viewWorkFlowMapper.selectCount(queryWrapper));
			hashMapOne.put("name", "全部");
			hashMapOne.put("badge", hashMapTwo);
			list.add(hashMapOne);
			
			Arrays.stream(stateList).forEach(string -> list.add(makeMap(string,workFlowEntity)));
			queryWrapper.eq(ViewWorkFlowEntity::getStatus, "强制关单");
			hashMapfour.put("value", viewWorkFlowMapper.selectCount(queryWrapper));
			hashMapthree.put("name", "强制关单");
			hashMapthree.put("badge", hashMapfour);
			list.add(hashMapthree);

			
	 		return list;
	 	};
	 	
	 	public HashMap<String, Object> makeMap(String status, WorkFlowEntity workFlowEntity){
	 		HashMap<String, Object> hashMapOne = new HashMap<String,Object>();
	 		HashMap<String, Object> hashMapTwo = new HashMap<String,Object>();
	 		LambdaQueryWrapper<ViewWorkFlowEntity> queryWrapper = new LambdaQueryWrapper<>();
	 		queryWrapper.like(StringUtils.isNotEmpty(workFlowEntity.getWorkOrderNo()), ViewWorkFlowEntity::getWorkOrderNo, workFlowEntity.getWorkOrderNo());
			queryWrapper.eq(StringUtils.isNotEmpty(workFlowEntity.getWorkPlace()), ViewWorkFlowEntity::getWorkPlace, workFlowEntity.getWorkPlace());
			queryWrapper.like(StringUtils.isNotEmpty(workFlowEntity.getPatientName()), ViewWorkFlowEntity::getPatientName, workFlowEntity.getPatientName());
			
			queryWrapper.ge(StringUtils.isNotEmpty(workFlowEntity.getCreatedStartDt()) , ViewWorkFlowEntity::getCreatedDt, workFlowEntity.getCreatedStartDt()); // 大于等于
			queryWrapper.le(StringUtils.isNotEmpty(workFlowEntity.getCreatedEndDt()), ViewWorkFlowEntity::getCreatedDt, workFlowEntity.getCreatedEndDt());// 小于等于
			queryWrapper.eq(ViewWorkFlowEntity::getStatus, status);
			hashMapTwo.put("value", viewWorkFlowMapper.selectCount(queryWrapper));
			hashMapOne.put("name", status);
			hashMapOne.put("badge", hashMapTwo);
			
			return hashMapOne;
	 	};
	 	
	 	/**
	 	 * 按照工作流id查询本id的数据
	 	 */
		@Override
	 	public List<WorkFlowEntity> findWorkFlowList(WorkFlowEntity workFlowEntity) throws Exception{
			
			LambdaQueryWrapper<WorkFlowEntity> qw = new LambdaQueryWrapper<>();
			qw.eq(workFlowEntity.getWorkOrderNo() != null, WorkFlowEntity::getWorkOrderNo, workFlowEntity.getWorkOrderNo());
			List<WorkFlowEntity> list = workFlowMapper.selectList(qw);
			return list;
	 	}
		/**
		 * 带有分页的视图查询，通过倒序查询到以工单id分组的数据。视图名为select_as_physical_distribution_group_by_work_order_no
		 */
		@Override
	 	public  HashMap<String, Object> findViewToWokeList(WorkFlowEntity workFlowEntity) throws Exception{
			LambdaQueryWrapper<ViewWorkFlowEntity> queryWrapper = new LambdaQueryWrapper<>();
			queryWrapper.like(StringUtils.isNotEmpty(workFlowEntity.getWorkOrderNo()), ViewWorkFlowEntity::getWorkOrderNo, workFlowEntity.getWorkOrderNo());
			queryWrapper.eq(StringUtils.isNotEmpty(workFlowEntity.getWorkPlace()), ViewWorkFlowEntity::getWorkPlace, workFlowEntity.getWorkPlace());
			queryWrapper.like(StringUtils.isNotEmpty(workFlowEntity.getPatientName()), ViewWorkFlowEntity::getPatientName, workFlowEntity.getPatientName());
			queryWrapper.eq(StringUtils.isNotEmpty(workFlowEntity.getStatus()), ViewWorkFlowEntity::getStatus, workFlowEntity.getStatus());
			queryWrapper.ge(StringUtils.isNotEmpty(workFlowEntity.getCreatedStartDt()) , ViewWorkFlowEntity::getCreatedDt, workFlowEntity.getCreatedStartDt()); // 大于等于
			queryWrapper.le(StringUtils.isNotEmpty(workFlowEntity.getCreatedEndDt()), ViewWorkFlowEntity::getCreatedDt, workFlowEntity.getCreatedEndDt());// 小于等于
			queryWrapper.orderByDesc(ViewWorkFlowEntity::getSid);
			Page<ViewWorkFlowEntity> page = new Page<>(workFlowEntity.getPageNum(), workFlowEntity.getPageSize());
			viewWorkFlowMapper.selectPage(page, queryWrapper);
			HashMap<String, Object> hashMap = new HashMap<String, Object>();
			List<ViewWorkFlowEntity> list = page.getRecords();
			Long current = page.getTotal();
			hashMap.put("count", current);
			hashMap.put("data", list);
			return hashMap;
		}

		/**
		 * 新增方法，若没有传过来工单号的情况下需要生成工单号。如果传过来工单号，则需要新增的内容中增加工单的内容
		 * @throws Exception
		 */
		@Override
	 	public Integer addWorkFlow(WorkFlowEntity workFlowEntity,List<Role> roleList, UserData user) throws Exception{
			
			if(workFlowEntity.getWorkOrderNo()==null || workFlowEntity.getWorkOrderNo()=="") {
				workFlowEntity.setWorkOrderNo(makeWorkFlowOrderId());
				workFlowEntity.setStatus("工单开始");
				workFlowEntity.setCreatedBy(user.getUserName());
				return workFlowMapper.insert(workFlowEntity);
			}
			// 查询本工单最后一个状态
			QueryWrapper<WorkFlowEntity>queryWrapper = new QueryWrapper<>();
			queryWrapper.select("*").eq("work_order_no", workFlowEntity.getWorkOrderNo()).orderByDesc("sid");
			List<WorkFlowEntity> workFlowEntityList = workFlowMapper.selectList(queryWrapper);
			WorkFlowEntity lastEntity = workFlowEntityList.get(0);  
			String state = lastEntity.getStatus();
			if("强制关单".equals(workFlowEntity.getStatus())) {
				if("己煎药送回".equals(state)) {
					throw new Exception("己煎药送回不可关单");
				}
				if(!StringUtils.isNotEmpty(workFlowEntity.getReason())) {
					throw new Exception("强制关单未输入原因");
				}
				workFlowEntity.setCreatedBy(user.getUserName());
	        	workFlowEntity.setCreatedDt(new Date());
	        	return workFlowMapper.insert(workFlowEntity);
				
			}
		

			
		
			String nextStatus = null;
			
			 for (int i = 0; i < stateList.length; i++) {  
		            if (stateList[i].equals(state)) {  
		                // 检查是否不是最后一个元素  
		                if (i < stateList.length - 1) {  
		                    // 获取下一个状态  
		                	nextStatus = stateList[i + 1];  
		                    break; // 找到后退出循环  
		                } else {  
		                    // 已经是最后一个状态了，没有下一个状态  
		                    
		                }  
		            }  
		        } 
			 workFlowEntity.setStatus(nextStatus);
			 
			 // 输出结果  
		        if (nextStatus != null) {  
		        	workFlowEntity.setCreatedBy(user.getUserName());
		        	workFlowEntity.setCreatedDt(new Date());
		        	return workFlowMapper.insert(workFlowEntity);
		        } else {  
		        	return null;
		        }  
			
		}

		private String makeWorkFlowOrderId() throws Exception{

			// 查询id最大的那个订单号 然后截取最后四位，将其转换成数字，然后给这个数字加1
			QueryWrapper<WorkFlowEntity> queryWrapper = new QueryWrapper<>();
			queryWrapper.orderByDesc("sid");
			 // 获取当前日期  
	        LocalDate today = LocalDate.now();  
	          
	        // 将当前日期转换为 LocalDateTime，时间部分设置为 00:00:00  
	        LocalDateTime midnight = today.atStartOfDay();  
	          
	        // 转换为 Date 对象，假设你的系统默认时区是合适的  
	        Date dateMidnight = Date.from(midnight.atZone(ZoneId.systemDefault()).toInstant()); 
			queryWrapper.ge("created_dt",dateMidnight);
			Page<WorkFlowEntity> page = new Page<>(1, 1);
			workFlowMapper.selectPage(page, queryWrapper);
			List<WorkFlowEntity> list = page.getRecords();
			System.out.println(list.toString());				
			System.out.println("+++++++++++++++++++++++++++++++++");
			// 获取当前日期并格式化为YYYYmmdd
			SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
			String currentDate = sdf.format(new Date());
			if(list.size()>0) {
				String	str = list.get(0).getWorkOrderNo();
				// 截取最后四位
				// 然后返回AS + 当前YYYYmmdd + 刚才的数字
				String lastFourDigits = str.substring(str.length() - 4);
				// 转换为整数并加1
				int number = Integer.parseInt(lastFourDigits) + 1;
				String formattedNumber = String.format("%04d", number);
				System.out.println(formattedNumber);				
				System.out.println("+++++++++++++++++++++++++++++++++");


				// 生成最终的字符串
				String finalString = "AS" + currentDate + formattedNumber;
				return finalString;
			}else {
				return 	"AS" + currentDate + "0001";

			}
		}
}
